==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d1/d00/classErrorMessageData.js <==
var classErrorMessageData =
[
    [ "ErrorMessageData", "d1/d00/classErrorMessageData.html#a8580f3bc18b610f8601783d3c5d2e019", null ],
    [ "~ErrorMessageData", "d1/d00/classErrorMessageData.html#a39ef0fc550e64d4632c99607ee05ec5f", null ],
    [ "ErrorMessageData", "d1/d00/classErrorMessageData.html#a105854b915bd4603c2cefe548f6e1a80", null ],
    [ "CopyOutDParams", "d1/d00/classErrorMessageData.html#a4239a4041d7c8f3804b7ed569fbbb1a9", null ],
    [ "HasFace", "d1/d00/classErrorMessageData.html#a23d91206fccba6eea4e4fb24f0dd1cd2", null ],
    [ "SetDParam", "d1/d00/classErrorMessageData.html#ae333f09801b43822f22c1bf4bd35926b", null ],
    [ "SetDParamStr", "d1/d00/classErrorMessageData.html#aa15007ca767e7dbd05566cb643828e4d", null ],
    [ "decode_params", "d1/d00/classErrorMessageData.html#a502ca1380e7ecfd690bc1d09622a1ff4", null ],
    [ "detailed_msg", "d1/d00/classErrorMessageData.html#ad64040c990af1defb8ef31de5741a7a3", null ],
    [ "duration", "d1/d00/classErrorMessageData.html#ac6f5f347536d1c26cb4d5d3e005a7c90", null ],
    [ "face", "d1/d00/classErrorMessageData.html#a2733496d0387a16697a80fb419807197", null ],
    [ "position", "d1/d00/classErrorMessageData.html#a4c6f5becb55832913e6cc82a831c28f2", null ],
    [ "strings", "d1/d00/classErrorMessageData.html#ad600939096bd90031083deb954199950", null ],
    [ "summary_msg", "d1/d00/classErrorMessageData.html#ae8e30ca1a3b324715d387105e72a9d21", null ],
    [ "textref_stack", "d1/d00/classErrorMessageData.html#ab4963c3dfbee182f757b9c5432fc9705", null ],
    [ "textref_stack_grffile", "d1/d00/classErrorMessageData.html#a59e0ba7caa4c54400d651212da18aa99", null ],
    [ "textref_stack_size", "d1/d00/classErrorMessageData.html#a2a526d301c7981f84e397ff90f79168f", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d1/d00/classErrorMessageData.js <==
var classErrorMessageData =
[
    [ "ErrorMessageData", "d1/d00/classErrorMessageData.html#a8580f3bc18b610f8601783d3c5d2e019", null ],
    [ "~ErrorMessageData", "d1/d00/classErrorMessageData.html#a39ef0fc550e64d4632c99607ee05ec5f", null ],
    [ "ErrorMessageData", "d1/d00/classErrorMessageData.html#a7eea61662467a7a665b3b69a805a483d", null ],
    [ "CopyOutDParams", "d1/d00/classErrorMessageData.html#a4239a4041d7c8f3804b7ed569fbbb1a9", null ],
    [ "HasFace", "d1/d00/classErrorMessageData.html#a23d91206fccba6eea4e4fb24f0dd1cd2", null ],
    [ "SetDParam", "d1/d00/classErrorMessageData.html#ae333f09801b43822f22c1bf4bd35926b", null ],
    [ "SetDParamStr", "d1/d00/classErrorMessageData.html#aa15007ca767e7dbd05566cb643828e4d", null ],
    [ "decode_params", "d1/d00/classErrorMessageData.html#a502ca1380e7ecfd690bc1d09622a1ff4", null ],
    [ "detailed_msg", "d1/d00/classErrorMessageData.html#ad64040c990af1defb8ef31de5741a7a3", null ],
    [ "display_timer", "d1/d00/classErrorMessageData.html#a10c2b224a030af1ec214ba5551b46977", null ],
    [ "face", "d1/d00/classErrorMessageData.html#a2733496d0387a16697a80fb419807197", null ],
    [ "position", "d1/d00/classErrorMessageData.html#a4c6f5becb55832913e6cc82a831c28f2", null ],
    [ "strings", "d1/d00/classErrorMessageData.html#ad600939096bd90031083deb954199950", null ],
    [ "summary_msg", "d1/d00/classErrorMessageData.html#ae8e30ca1a3b324715d387105e72a9d21", null ],
    [ "textref_stack", "d1/d00/classErrorMessageData.html#ab4963c3dfbee182f757b9c5432fc9705", null ],
    [ "textref_stack_grffile", "d1/d00/classErrorMessageData.html#a59e0ba7caa4c54400d651212da18aa99", null ],
    [ "textref_stack_size", "d1/d00/classErrorMessageData.html#a2a526d301c7981f84e397ff90f79168f", null ]
];
